@@ -1,29 +1,40 @@
 import tempfile
-from tqdm.auto import tqdm
 
 import matplotlib.pyplot as plt
 import numpy as np
+from skfem import Basis, ElementTriP0, Mesh
+from tqdm.auto import tqdm
 
-from skfem import Mesh, Basis, ElementTriP0
-
-from femwell.mode_solver import compute_modes, plot_mode, calculate_overlap, calculate_hfield
+from femwell.mode_solver import (
+    calculate_hfield,
+    calculate_overlap,
+    compute_modes,
+    plot_mode,
+)
 from femwell.waveguide import mesh_waveguide
 
-widths = [.5, .8]
+widths = [0.5, 0.8]
 
 modes = []
 
 for width in widths:
     with tempfile.TemporaryDirectory() as tmpdirname:
-        mesh = mesh_waveguide(wsim=2, hclad=.7, hbox=.5, wcore=width, hcore=0.22, filename=f'{tmpdirname}/mesh.msh')
-        mesh = Mesh.load(f'{tmpdirname}/mesh.msh')
+        mesh = mesh_waveguide(
+            wsim=2,
+            hclad=0.7,
+            hbox=0.5,
+            wcore=width,
+            hcore=0.22,
+            filename=f"{tmpdirname}/mesh.msh",
+        )
+        mesh = Mesh.load(f"{tmpdirname}/mesh.msh")
 
     basis0 = Basis(mesh, ElementTriP0(), intorder=4)
     epsilon = basis0.zeros()
-    epsilon[basis0.get_dofs(elements='core')] = 3.4777 ** 2
-    epsilon[basis0.get_dofs(elements='clad')] = 1.444 ** 2
-    epsilon[basis0.get_dofs(elements='box')] = 1.444 ** 2
-    #basis0.plot(epsilon, colorbar=True).show()
+    epsilon[basis0.get_dofs(elements="core")] = 3.4777**2
+    epsilon[basis0.get_dofs(elements="clad")] = 1.444**2
+    epsilon[basis0.get_dofs(elements="box")] = 1.444**2
+    # basis0.plot(epsilon, colorbar=True).show()
 
     lams, basis, xs = compute_modes(basis0, epsilon, wavelength=1.55, mu_r=1, num_modes=10)
 
@@ -49,18 +60,18 @@ for mode_a, mode_b in zip(modes[:-1], modes[1:]):
     plt.colorbar()
     plt.show()
 
-    z = np.abs(integrals)**2
+    z = np.abs(integrals) ** 2
 
     fig, axCenter = plt.subplots(figsize=(8, 8))
-    fig.subplots_adjust(.05,.1,.95,.95)
+    fig.subplots_adjust(0.05, 0.1, 0.95, 0.95)
 
     from mpl_toolkits.axes_grid1 import make_axes_locatable
 
     divider = make_axes_locatable(axCenter)
-    axvert = divider.append_axes('right', size='30%', pad=0.5)
-    axhoriz = divider.append_axes('top', size='20%', pad=0.25)
+    axvert = divider.append_axes("right", size="30%", pad=0.5)
+    axhoriz = divider.append_axes("top", size="20%", pad=0.25)
 
-    axCenter.imshow(z, origin='lower', cmap='jet')
+    axCenter.imshow(z, origin="lower", cmap="jet")
     axhoriz.plot(range(np.shape(z)[1]), np.sum(z, 0))
     axvert.plot(np.sum(z, 1), range(np.shape(z)[0]))
 
