@@ -1,21 +1,28 @@
-from typing import Dict, Optional, Tuple, List
+from collections import OrderedDict
+from typing import Dict, List, Optional, Tuple
 
+import gmsh
 import numpy as np
 import pygmsh
-import gmsh
 import shapely
-from shapely.geometry import Point, LineString, Polygon, MultiPolygon, LinearRing, MultiLineString
-from shapely.ops import split, linemerge
+from shapely.geometry import (
+    LinearRing,
+    LineString,
+    MultiLineString,
+    MultiPolygon,
+    Point,
+    Polygon,
+)
+from shapely.ops import linemerge, split
 
-from collections import OrderedDict
 
-class MeshTracker():
-    def __init__(self, model, atol=1E-3):
-        '''
-        Map between shapely and gmsh 
+class MeshTracker:
+    def __init__(self, model, atol=1e-3):
+        """
+        Map between shapely and gmsh
         Shapely is useful for built-in geometry equivalencies and extracting orientation, instead of doing it manually
         We can also track information about the entities using labels (useful for selective mesh refinement later)
-        '''
+        """
         self.shapely_points = []
         self.gmsh_points = []
         self.points_labels = []
@@ -31,6 +38,7 @@ class MeshTracker():
     """
     Retrieve existing geometry
     """
+
     def get_point_index(self, xy_point):
         for index, shapely_point in enumerate(self.shapely_points):
             if xy_point.equals_exact(shapely_point, self.atol):
@@ -61,9 +69,10 @@ class MeshTracker():
     """
     Channel loop utilities (no need to track)
     """
+
     def xy_channel_loop_from_vertices(self, vertices, label):
         edges = []
-        for vertex1, vertex2 in [(vertices[i], vertices[i + 1]) for i in range(len(vertices)-1)]:
+        for vertex1, vertex2 in [(vertices[i], vertices[i + 1]) for i in range(len(vertices) - 1)]:
             gmsh_line, orientation = self.add_get_xy_segment(vertex1, vertex2, label)
             if orientation:
                 edges.append(gmsh_line)
@@ -74,6 +83,7 @@ class MeshTracker():
     """
     Adding geometry
     """
+
     def add_get_point(self, shapely_xy_point, label=None):
         """
         Add a shapely point to the gmsh model, or retrieve the existing gmsh model points with equivalent coordinates (within tol.)
@@ -92,7 +102,6 @@ class MeshTracker():
             self.points_labels.append(label)
         return gmsh_point
 
-
     def add_get_xy_segment(self, shapely_xy_point1, shapely_xy_point2, label):
         """
         Add a shapely segment (2-point line) to the gmsh model in the xy plane, or retrieve the existing gmsh segment with equivalent coordinates (within tol.)
@@ -101,13 +110,20 @@ class MeshTracker():
             shapely_xy_point1 (shapely.geometry.Point): first x, y coordinates
             shapely_xy_point2 (shapely.geometry.Point): second x, y coordinates
         """
-        index, orientation = self.get_xy_segment_index_and_orientation(shapely_xy_point1, shapely_xy_point2)
+        index, orientation = self.get_xy_segment_index_and_orientation(
+            shapely_xy_point1, shapely_xy_point2
+        )
         if index is not None:
             gmsh_segment = self.gmsh_xy_segments[index]
             self.xy_segments_secondary_labels[index] = label
         else:
-            gmsh_segment = self.model.add_line(self.add_get_point(shapely_xy_point1), self.add_get_point(shapely_xy_point2))
-            self.shapely_xy_segments.append(shapely.geometry.LineString([shapely_xy_point1, shapely_xy_point2]))
+            gmsh_segment = self.model.add_line(
+                self.add_get_point(shapely_xy_point1),
+                self.add_get_point(shapely_xy_point2),
+            )
+            self.shapely_xy_segments.append(
+                shapely.geometry.LineString([shapely_xy_point1, shapely_xy_point2])
+            )
             self.gmsh_xy_segments.append(gmsh_segment)
             self.xy_segments_main_labels.append(label)
             self.xy_segments_secondary_labels.append(None)
@@ -121,8 +137,12 @@ class MeshTracker():
             shapely_xy_curve (shapely.geometry.LineString): curve
         """
         segments = []
-        for shapely_xy_point1, shapely_xy_point2 in zip(shapely_xy_curve.coords[:-1], shapely_xy_curve.coords[1:]):
-            gmsh_segment, orientation = self.add_get_xy_segment(Point(shapely_xy_point1), Point(shapely_xy_point2), label)
+        for shapely_xy_point1, shapely_xy_point2 in zip(
+            shapely_xy_curve.coords[:-1], shapely_xy_curve.coords[1:]
+        ):
+            gmsh_segment, orientation = self.add_get_xy_segment(
+                Point(shapely_xy_point1), Point(shapely_xy_point2), label
+            )
             if orientation:
                 segments.append(gmsh_segment)
             else:
@@ -163,8 +183,10 @@ class MeshTracker():
 def break_line(line, other_line):
     intersections = line.intersection(other_line)
     if not intersections.is_empty:
-        for intersection in intersections.geoms if hasattr(intersections, 'geoms') else [intersections]:
-            if intersection.geom_type != 'Point':
+        for intersection in (
+            intersections.geoms if hasattr(intersections, "geoms") else [intersections]
+        ):
+            if intersection.geom_type != "Point":
                 new_coords_start, new_coords_end = intersection.boundary.geoms
                 line = linemerge(split(line, new_coords_start))
                 line = linemerge(split(line, new_coords_end))
@@ -178,12 +200,10 @@ def mesh_from_polygons(
     default_resolution_max: float = 0.5,
     filename: Optional[str] = None,
     gmsh_algorithm: int = 5,
-    global_quad: Optional[bool] = False
+    global_quad: Optional[bool] = False,
 ):
-
     import gmsh
 
-
     with pygmsh.occ.geometry.Geometry() as geometry:
         # geometry = pygmsh.occ.geometry.Geometry()
         geometry.characteristic_length_min = default_resolution_min
@@ -194,9 +214,13 @@ def mesh_from_polygons(
 
         # Break up shapes in order so that plane is tiled with non-overlapping layers
         shapes_tiled_dict = OrderedDict()
-        for lower_index, (lower_name, lower_shape) in reversed(list(enumerate(shapes_dict.items()))):
+        for lower_index, (lower_name, lower_shape) in reversed(
+            list(enumerate(shapes_dict.items()))
+        ):
             diff_shape = lower_shape
-            for higher_index, (higher_name, higher_shape) in reversed(list(enumerate(shapes_dict.items()))[:lower_index]):
+            for higher_index, (higher_name, higher_shape) in reversed(
+                list(enumerate(shapes_dict.items()))[:lower_index]
+            ):
                 diff_shape = diff_shape.difference(higher_shape)
             shapes_tiled_dict[lower_name] = diff_shape
 
@@ -206,21 +230,43 @@ def mesh_from_polygons(
         for first_index, (first_name, first_shape) in enumerate(shapes_dict.items()):
             first_shape = shapes_tiled_dict[first_name]
             broken_shapes = []
-            for first_shape in first_shape.geoms if hasattr(first_shape, 'geoms') else [first_shape]:
+            for first_shape in (
+                first_shape.geoms if hasattr(first_shape, "geoms") else [first_shape]
+            ):
                 # First line exterior
-                first_exterior_line = LineString(first_shape.exterior) if first_shape.geom_type == "Polygon" else first_shape
+                first_exterior_line = (
+                    LineString(first_shape.exterior)
+                    if first_shape.geom_type == "Polygon"
+                    else first_shape
+                )
                 for second_name, second_shapes in shapes_dict.items():
                     # Do not compare to itself
                     if second_name != first_name:
                         second_shapes = shapes_tiled_dict[second_name]
-                        for second_shape in second_shapes.geoms if hasattr(second_shapes, 'geoms') else [second_shapes]:
+                        for second_shape in (
+                            second_shapes.geoms
+                            if hasattr(second_shapes, "geoms")
+                            else [second_shapes]
+                        ):
                             # Second line exterior
-                            second_exterior_line = LineString(second_shape.exterior) if second_shape.geom_type == "Polygon" else second_shape
-                            first_exterior_line = break_line(first_exterior_line, second_exterior_line)
+                            second_exterior_line = (
+                                LineString(second_shape.exterior)
+                                if second_shape.geom_type == "Polygon"
+                                else second_shape
+                            )
+                            first_exterior_line = break_line(
+                                first_exterior_line, second_exterior_line
+                            )
                             # Second line interiors
-                            for second_interior_line in second_shape.interiors if second_shape.geom_type == "Polygon" else []:
+                            for second_interior_line in (
+                                second_shape.interiors
+                                if second_shape.geom_type == "Polygon"
+                                else []
+                            ):
                                 second_interior_line = LineString(second_interior_line)
-                                first_exterior_line = break_line(first_exterior_line, second_interior_line)
+                                first_exterior_line = break_line(
+                                    first_exterior_line, second_interior_line
+                                )
                 # First line interiors
                 if first_shape.geom_type in ["Polygon", "MultiPolygon"]:
                     first_shape_interiors = []
@@ -229,24 +275,46 @@ def mesh_from_polygons(
                         for second_name, second_shapes in shapes_dict.items():
                             if second_name != first_name:
                                 second_shapes = shapes_tiled_dict[second_name]
-                                for second_shape in second_shapes.geoms if hasattr(second_shapes, 'geoms') else [second_shapes]:
+                                for second_shape in (
+                                    second_shapes.geoms
+                                    if hasattr(second_shapes, "geoms")
+                                    else [second_shapes]
+                                ):
                                     # Exterior
-                                    second_exterior_line = LineString(second_shape.exterior) if second_shape.geom_type == "Polygon" else second_shape
-                                    first_interior_line = break_line(first_interior_line, second_exterior_line)
+                                    second_exterior_line = (
+                                        LineString(second_shape.exterior)
+                                        if second_shape.geom_type == "Polygon"
+                                        else second_shape
+                                    )
+                                    first_interior_line = break_line(
+                                        first_interior_line, second_exterior_line
+                                    )
                                     # Interiors
-                                    for second_interior_line in second_shape.interiors if second_shape.geom_type == "Polygon" else []:
+                                    for second_interior_line in (
+                                        second_shape.interiors
+                                        if second_shape.geom_type == "Polygon"
+                                        else []
+                                    ):
                                         second_interior_line = LineString(second_interior_line)
-                                        intersections = first_interior_line.intersection(second_interior_line)
-                                        first_interior_line = break_line(first_interior_line, second_interior_line)
+                                        intersections = first_interior_line.intersection(
+                                            second_interior_line
+                                        )
+                                        first_interior_line = break_line(
+                                            first_interior_line, second_interior_line
+                                        )
                         first_shape_interiors.append(first_interior_line)
-                if first_shape.geom_type in ["Polygon", "MultiPolygon"]: 
+                if first_shape.geom_type in ["Polygon", "MultiPolygon"]:
                     broken_shapes.append(Polygon(first_exterior_line, holes=first_shape_interiors))
                 else:
                     broken_shapes.append(LineString(first_exterior_line))
-            if first_shape.geom_type in ["Polygon", "MultiPolygon"]: 
-                polygons_broken_dict[first_name] = MultiPolygon(broken_shapes) if len(broken_shapes) > 1 else broken_shapes[0]
+            if first_shape.geom_type in ["Polygon", "MultiPolygon"]:
+                polygons_broken_dict[first_name] = (
+                    MultiPolygon(broken_shapes) if len(broken_shapes) > 1 else broken_shapes[0]
+                )
             else:
-                lines_broken_dict[first_name] = MultiLineString(broken_shapes) if len(broken_shapes) > 1 else broken_shapes[0]
+                lines_broken_dict[first_name] = (
+                    MultiLineString(broken_shapes) if len(broken_shapes) > 1 else broken_shapes[0]
+                )
 
         # Add lines, reusing line segments
         meshtracker = MeshTracker(model=model)
@@ -265,25 +333,31 @@ def mesh_from_polygons(
             mesh_resolution = mesh_setting["resolution"]
             gmsh.model.mesh.field.add("MathEval", n)
             gmsh.model.mesh.field.setString(n, "F", f"{mesh_resolution}")
-            gmsh.model.mesh.field.add("Restrict", n+1)
-            gmsh.model.mesh.field.setNumber(n+1, "InField", n)
-            gmsh.model.mesh.field.setNumbers(n+1, "SurfacesList", meshtracker.get_gmsh_xy_surfaces_from_label(label))
+            gmsh.model.mesh.field.add("Restrict", n + 1)
+            gmsh.model.mesh.field.setNumber(n + 1, "InField", n)
+            gmsh.model.mesh.field.setNumbers(
+                n + 1,
+                "SurfacesList",
+                meshtracker.get_gmsh_xy_surfaces_from_label(label),
+            )
             # Around surface
             mesh_distance = mesh_setting["distance"]
-            gmsh.model.mesh.field.add("Distance", n+2)
-            gmsh.model.mesh.field.setNumbers(n+2, "CurvesList", meshtracker.get_gmsh_xy_lines_from_label(label))
-            gmsh.model.mesh.field.setNumber(n+2, "Sampling", 100)
-            gmsh.model.mesh.field.add("Threshold", n+3)
-            gmsh.model.mesh.field.setNumber(n+3, "InField", n+2)
-            gmsh.model.mesh.field.setNumber(n+3, "SizeMin", mesh_resolution)
-            gmsh.model.mesh.field.setNumber(n+3, "SizeMax", default_resolution_max)
-            gmsh.model.mesh.field.setNumber(n+3, "DistMin", 0)
-            gmsh.model.mesh.field.setNumber(n+3, "DistMax", mesh_distance)
-           # Save and increment
-            refinement_fields.extend((n+1, n+3))
+            gmsh.model.mesh.field.add("Distance", n + 2)
+            gmsh.model.mesh.field.setNumbers(
+                n + 2, "CurvesList", meshtracker.get_gmsh_xy_lines_from_label(label)
+            )
+            gmsh.model.mesh.field.setNumber(n + 2, "Sampling", 100)
+            gmsh.model.mesh.field.add("Threshold", n + 3)
+            gmsh.model.mesh.field.setNumber(n + 3, "InField", n + 2)
+            gmsh.model.mesh.field.setNumber(n + 3, "SizeMin", mesh_resolution)
+            gmsh.model.mesh.field.setNumber(n + 3, "SizeMax", default_resolution_max)
+            gmsh.model.mesh.field.setNumber(n + 3, "DistMin", 0)
+            gmsh.model.mesh.field.setNumber(n + 3, "DistMax", mesh_distance)
+            # Save and increment
+            refinement_fields.extend((n + 1, n + 3))
             n += 4
 
-        if global_quad:        
+        if global_quad:
             gmsh.option.setNumber("Mesh.Algorithm", 8)
             gmsh.option.setNumber("Mesh.RecombineAll", 1)
 
@@ -304,7 +378,10 @@ def mesh_from_polygons(
         # Extract all unique lines (TODO: identify interfaces in label)
         i = 0
         for index, line in enumerate(meshtracker.gmsh_xy_segments):
-            model.add_physical(line, f"{meshtracker.xy_segments_main_labels[index]}_{meshtracker.xy_segments_secondary_labels[index]}_{i}")
+            model.add_physical(
+                line,
+                f"{meshtracker.xy_segments_main_labels[index]}_{meshtracker.xy_segments_secondary_labels[index]}_{i}",
+            )
             i += 1
 
         mesh = geometry.generate_mesh(dim=2, verbose=True)
@@ -316,7 +393,6 @@ def mesh_from_polygons(
 
 
 if __name__ == "__main__":
-
     import gmsh
 
     wmode = 1
@@ -329,40 +405,52 @@ if __name__ == "__main__":
     offset_core2 = 1
 
     # Lines can be added, which is useful to define boundary conditions at various simulation edges
-    left_edge = LineString([Point(-wsim/2, -hcore/2  - hbox), 
-                            Point(-wsim/2, -hcore/2 + hclad)])
-    right_edge = LineString([Point(wsim/2, -hcore/2  - hbox), 
-                            Point(wsim/2, -hcore/2 + hclad)])
-    top_edge = LineString([Point(-wsim/2, -hcore/2 + hclad), 
-                            Point(wsim/2, -hcore/2 + hclad)])
-    bottom_edge = LineString([Point(-wsim/2, -hcore/2  - hbox), 
-                            Point(wsim/2, -hcore/2  - hbox)])
+    left_edge = LineString(
+        [Point(-wsim / 2, -hcore / 2 - hbox), Point(-wsim / 2, -hcore / 2 + hclad)]
+    )
+    right_edge = LineString(
+        [Point(wsim / 2, -hcore / 2 - hbox), Point(wsim / 2, -hcore / 2 + hclad)]
+    )
+    top_edge = LineString(
+        [Point(-wsim / 2, -hcore / 2 + hclad), Point(wsim / 2, -hcore / 2 + hclad)]
+    )
+    bottom_edge = LineString(
+        [Point(-wsim / 2, -hcore / 2 - hbox), Point(wsim / 2, -hcore / 2 - hbox)]
+    )
 
     # Polygons not only have an edge, but an interior
-    core = Polygon([
-            Point(-wcore/2, -hcore/2 + offset_core),
-            Point(-wcore/2, hcore/2 + offset_core),
-            Point(wcore/2, hcore/2 + offset_core),
-            Point(wcore/2, -hcore/2 + offset_core),
-        ])
-    core2 = Polygon([
-            Point(-wcore/2, -hcore/2 + offset_core2),
-            Point(-wcore/2, hcore/2 + offset_core2),
-            Point(wcore/2, hcore/2 + offset_core2),
-            Point(wcore/2, -hcore/2 + offset_core2),
-        ])
-    clad = Polygon([
-            Point(-wsim/2, -hcore/2),
-            Point(-wsim/2, -hcore/2 + hclad),
-            Point(wsim/2, -hcore/2 + hclad),
-            Point(wsim/2, -hcore/2),
-        ])
-    box = Polygon([
-            Point(-wsim/2, -hcore/2),
-            Point(-wsim/2, -hcore/2 - hbox),
-            Point(wsim/2, -hcore/2 - hbox),
-            Point(wsim/2, -hcore/2),
-        ])
+    core = Polygon(
+        [
+            Point(-wcore / 2, -hcore / 2 + offset_core),
+            Point(-wcore / 2, hcore / 2 + offset_core),
+            Point(wcore / 2, hcore / 2 + offset_core),
+            Point(wcore / 2, -hcore / 2 + offset_core),
+        ]
+    )
+    core2 = Polygon(
+        [
+            Point(-wcore / 2, -hcore / 2 + offset_core2),
+            Point(-wcore / 2, hcore / 2 + offset_core2),
+            Point(wcore / 2, hcore / 2 + offset_core2),
+            Point(wcore / 2, -hcore / 2 + offset_core2),
+        ]
+    )
+    clad = Polygon(
+        [
+            Point(-wsim / 2, -hcore / 2),
+            Point(-wsim / 2, -hcore / 2 + hclad),
+            Point(wsim / 2, -hcore / 2 + hclad),
+            Point(wsim / 2, -hcore / 2),
+        ]
+    )
+    box = Polygon(
+        [
+            Point(-wsim / 2, -hcore / 2),
+            Point(-wsim / 2, -hcore / 2 - hbox),
+            Point(wsim / 2, -hcore / 2 - hbox),
+            Point(wsim / 2, -hcore / 2),
+        ]
+    )
 
     # The order in which objects are inserted into the OrderedDict determines overrrides
     shapes = OrderedDict()
@@ -370,7 +458,7 @@ if __name__ == "__main__":
     shapes["right_edge"] = right_edge
     shapes["top_edge"] = top_edge
     shapes["bottom_edge"] = bottom_edge
-    shapes["core"] = core 
+    shapes["core"] = core
     shapes["core2"] = core2
     shapes["clad"] = clad
     shapes["box"] = box
@@ -389,7 +477,13 @@ if __name__ == "__main__":
     # resolutions["clad"] = {"resolution": 0.1, "dist_min": 0.01, "dist_max": 0.3}
 
     quad = False
-    mesh = mesh_from_polygons(shapes, resolutions, filename="mesh.msh", default_resolution_max=.3, global_quad=quad)
+    mesh = mesh_from_polygons(
+        shapes,
+        resolutions,
+        filename="mesh.msh",
+        default_resolution_max=0.3,
+        global_quad=quad,
+    )
 
     # gmsh.write("mesh.msh")
     # gmsh.clear()
@@ -416,4 +510,4 @@ if __name__ == "__main__":
         triangle_mesh = create_mesh(mesh_from_file, "quad", prune_z=True)
     else:
         triangle_mesh = create_mesh(mesh_from_file, "triangle", prune_z=True)
-    meshio.write("mesh.xdmf", triangle_mesh)
\ No newline at end of file
+    meshio.write("mesh.xdmf", triangle_mesh)
