@@ -1,5 +1,6 @@
+from femwell.mesh.mesh import mesh_from_Dict, mesh_from_OrderedDict
 from femwell.mesh.meshtracker import MeshTracker
-from femwell.mesh.mesh import mesh_from_OrderedDict, mesh_from_Dict
+
 __all__ = [
     "MeshTracker",
     "mesh_from_OrderedDict",
