@@ -4,8 +4,11 @@ import numpy as np
 from skfem import (
     Basis,
     BilinearForm,
+    ElementTetP1,
+    ElementTetP2,
     ElementTriP0,
     ElementTriP1,
+    ElementTriP2,
     LinearForm,
     Mesh,
     asm,
@@ -21,6 +24,7 @@ def solve_thermal(
     specific_conductivity: Dict[str, float],
     current_densities,
     fixed_boundaries,
+    order=1,
 ):
     """Thermal simulation.
 
@@ -34,11 +38,16 @@ def solve_thermal(
         basis, temperature profile
     """
 
+    if order == 1:
+        element = ElementTriP1() if basis0.mesh.dim() == 2 else ElementTetP1()
+    elif order == 2:
+        element = ElementTriP2() if basis0.mesh.dim() == 2 else ElementTetP2()
+
     @BilinearForm
     def conduction(u, v, w):
         return dot(w["thermal_conductivity"] * u.grad, v.grad)
 
-    basis = basis0.with_element(ElementTriP1())
+    basis = basis0.with_element(element)
 
     @LinearForm
     def unit_load(v, _):
